/**
 * Library for the Mobile Processing project - http://mobile.processing.org
 *
 * Copyright (c) 2007 Shawn Van Every
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 *
 * @author  Shawn Van Every
 * 
 */

package com.mobvcasting.msoundplayback;

import processing.core.*;

import java.io.ByteArrayInputStream;
import java.io.IOException;

import javax.microedition.media.*;
import javax.microedition.media.control.VideoControl;

public class MSoundPlayback 
{
	PMIDlet pMIDlet;
	
	Player mPlayer;	

	ByteArrayInputStream inStream;
	String mimeType;

	boolean soundPlaying = false;
		
	public MSoundPlayback(PMIDlet parent, byte[] inBytes, String mimeType) 
	{
		this.pMIDlet = parent;
		inStream = new ByteArrayInputStream(inBytes);
		this.mimeType = mimeType;
		
		initialize();
	}
	
	public void initialize()
	{
		try
		{
			mPlayer = Manager.createPlayer(inStream,mimeType);
			mPlayer.realize();
		}
		catch (MediaException e)
		{
			throw new RuntimeException(e.getMessage() + e.toString());
		} 
		catch (IOException e) 
		{
			throw new RuntimeException(e.getMessage() + e.toString());
		}
	}
	
	public void playSound()
	{
		try
		{
			mPlayer.start();
			
			soundPlaying = true;
		} 
		catch (MediaException e) 
		{
			throw new RuntimeException(e.getMessage() + e.toString());
		} 
	}

	public void stopSound() 
	{
		try 
		{
			mPlayer.stop();
	
			soundPlaying = false;
		}
		catch (MediaException e) 
		{
			throw new RuntimeException(e.getMessage() + e.toString());
		} 
	}
	
	public void closePlayer()
	{
		mPlayer.close();		
	}
}